@@ -1,12 +1,13 @@
-#! /usr/bin/env python 
+#! /usr/bin/env python
 #
 """
-gc3utils - A simple command-line frontend to distributed resources
+This is the main entry point for command `gc3utils`:command: -- a
+simple command-line frontend to distributed resources
 
 This is a generic front-end code; actual implementation of commands
-can be found in gc3utils/commands.py
+can be found in `gc3utils.commands`:mod:
 """
-# Copyright (C) 2009-2011 GC3, University of Zurich. All rights reserved.
+# Copyright (C) 2009-2012 GC3, University of Zurich. All rights reserved.
 #
 # Includes parts adapted from the ``bzr`` code, which is
 # copyright (C) 2005, 2006, 2007, 2008, 2009 Canonical Ltd
@@ -26,13 +27,14 @@ can be found in gc3utils/commands.py
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
+## stdlib imports
 import os
 import os.path
 import sys
 import warnings
 
+## local imports
 from gc3libs.exceptions import *
-
 import gc3utils
 
 
@@ -124,7 +126,9 @@ def main():
 
 Command `gc3utils` is a unified front-end to computing resources.
 You can get more help on a specific sub-command by typing::
+
   gc3utils COMMAND --help
+
 where command is one of these:
 """)
             import gc3utils.commands
@@ -141,11 +145,4 @@ where command is one of these:
         sys.stderr.write("Cannot find command '%s' in gc3utils; aborting now.\n" % PROG)
         return 1
     rc = cmd().run() # (*sys.argv[1:])
-
-    # Quick and dirty fix for bug http://code.google.com/p/gc3pie/issues/detail?id=182
-    # Should try to fix for real in next release.
-    # This redirects the stderr to /dev/null so we don't see the error.
-    f = open(os.devnull, 'w')
-    os.dup2(f.fileno(), sys.stderr.fileno())
-
     return rc
